@@ -6,6 +6,7 @@
 ## 2009 12 10 mixtures
 ## 2010 02 05 update signal-strength detection functions
 ## 2010 02 25 insertdim factor handling improved to retain ordering of levels
+## 2010-10-09 allow detectfn 6,7
 ############################################################################################
 
 ############################################################################################
@@ -570,8 +571,8 @@ secr.loglikfn <- function (beta, parindx, link, fixed, designD, design, design0
 
     #--------------------------------------------------------------------
     # Detection parameters
-    if (!detectfn %in% c(0:3,5,6,9,10,11))
-        stop ('detectfn can only take values in c(0:3,5,6,9,10,11)')
+    if (!detectfn %in% c(0:3,5,6,7,8,9,10,11))
+        stop ('detectfn can only take values in c(0:3,5,6,7,8,9,10,11)')
     realparval  <- makerealparameters (design, beta, parindx, link, fixed)
     realparval0 <- makerealparameters (design0, beta, parindx, link, fixed)  # naive
 
@@ -789,8 +790,8 @@ MRsecr.loglikfn <- function (beta, parindx, link, fixed, designD, design, design
     else sessionlevels <- 1
     nsession <- length(sessionlevels)
 
-    if (!detectfn %in% c(0:3,5,6))
-        stop ('detectfn can only take values 0 (halfnormal), 1 (hazard-rate), 2 (exponential), 3 (compound halfnormal, 5 (w-exponential) or 6 (annular normal)for now')
+    if (!detectfn %in% c(0:3,5,6,7))
+        stop ('detectfn can only take values 0 (halfnormal), 1 (hazard-rate), 2 (exponential), 3 (compound halfnormal, 5 (w-exponential), 6 (annular normal), 7 (cumulative lognormal) for now')
 
     #--------------------------------------------------------------------
     # Groups
@@ -988,9 +989,9 @@ MRsecr.loglikfn <- function (beta, parindx, link, fixed, designD, design, design
 make.lookup <- function (tempmat) {
 
     ## should add something to protect make.lookup from bad data...
-
     nrw <- nrow(tempmat)
     ncl <- ncol(tempmat)
+
     temp <- .C("makelookup",  PACKAGE='secr',
         as.double(tempmat),
         as.integer(nrw),
