@@ -347,7 +347,19 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     findvars.MS (timecov, vars, 3)      ## session-specific list
     findvars.MS (trapcov, vars, 4)      ## session-specific list
 
-    if (length(vars)>0) stop (paste('Covariate(s) ', paste(vars,collapse=','),'not found'))
+    if (length(vars)>0) {
+        if (!is.null(zcov)) {
+            if (is.data.frame(zcov))
+                znames <- names(zcov)
+            else
+                znames <- unlist(lapply(zcov, names))
+            if (any (vars %in% znames))
+                stop ('seems you are trying to use individual covariates in a full-likelihood model')
+        }
+        stop (paste('covariate(s) ', paste(vars,collapse=','),
+                                    'not found'))
+    }
+
     #------------------------------------------------
     # DOES NOT YET STANDARDIZE COVARIATES (cf Dmat)
 
@@ -372,7 +384,6 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     # list with one component per real parameter
     # each of these is a list with components 'model' and 'index'
 
-##    designMatrices <- lapply (models, make.designmatrix)
     designMatrices <- sapply (1:length(models), simplify=FALSE,
         function (x) make.designmatrix(models[[x]], names(models[x])))
     names(designMatrices) <- names(models)
