@@ -5,6 +5,7 @@
 ## last changed 2009 06 19, 2009 09 09 'seed' added 2009 10 27 new detector types
 ## 2009 11 12
 ## 2010 07 01 allow alphanumeric detection functions
+## 2010 10 09 annular normal and cumulative lognormal detection functions
 ## sim.resight 2009 10 08
 ############################################################################################
 
@@ -126,6 +127,8 @@ sim.capthist <- function (
         ##    3  compound halfnormal
         ##    4  uniform
         ##    5  w-exponential
+        ##    6  annular normal
+        ##    7  cumulative lognormal
         ##    9  binary signal strength (b0 = (beta0-c)/sdS, b1 = beta1/sdS)
         ##   10  signal strength (signal detectors only)
         ##   11  signal strength with spherical spreading (signal detectors only)
@@ -135,6 +138,8 @@ sim.capthist <- function (
         if (detectfn %in% c(0:4))  defaults <- list(g0 = 0.2, sigma = 25, z = 1)
 
         if (detectfn %in% c(5))    defaults <- list(g0 = 0.2, sigma = 25, w = 10)
+        if (detectfn %in% c(6))    defaults <- list(g0 = 0.2, sigma = 25, w = 10)
+        if (detectfn %in% c(7))    defaults <- list(g0 = 0.2, sigma = 25, z = 5)
         if (detectfn %in% c(9))  defaults <- list(b0 = 1, b1=-0.1, cutval = 60,
             tx = 'identity')
         if (detectfn %in% c(10,11))  defaults <- list(beta0 = 90, beta1=-0.2,
@@ -153,11 +158,12 @@ sim.capthist <- function (
         detectpar <- replacedefaults(defaults, detectpar)
 
     ## extended for uniform (detectfn=4) 2010-06-13
+    ## extended for annualr normal and cum lognormal 2010-10-09
     ##    if (detectfn %in% c(0,1,2,3,5)) {
-        if (detectfn %in% c(0,1,2,3,4,5)) {
+        if (detectfn %in% c(0,1,2,3,4,5,6,7)) {
             g0    <- expand(detectpar$g0, noccasions)
             sigma <- expand(detectpar$sigma, noccasions)
-            z     <- expand(ifelse(detectfn == 5, detectpar$w, detectpar$z), noccasions)
+            z     <- expand(ifelse(detectfn %in% c(5,6), detectpar$w, detectpar$z), noccasions)
             if (detector(traps) %in% c('count', 'quadratbinary','quadratcount', 'polygon'))
                 validatepar(g0, c(0,Inf))
             else validatepar(g0, c(0,1))
