@@ -120,6 +120,18 @@ void simsecr (
     int    *resultcode
 );
 
+double pfn (
+    int fn,
+    double d2val,
+    double g0,
+    double sigma,
+    double z,
+    double area,
+    double w2);
+
+void pdotpoint (double *xy, int *nxy, double *traps, int *kk,
+		int *fn, int *nocc, double *par, double *w2, double *value);
+
 void pdotpoly (double *xy, int *nxy, double *traps, int *nk, 
     int *kk, int *fn, int *nocc, double *par, double *value);
 
